pub struct InferredNeighbor {
pub comp_id: String,
pub terminal: &'static str,
pub neighbor_id: Option<String>,
pub role: NeighborRole,
}Expand description
An inferred role for one neighbour of one active-device terminal.
Fields
comp_id: StringOwning active device id (e.g. “V1”).
terminal: &'static strTerminal name (e.g. “plate”).
neighbor_id: Option<String>Neighbour component id across the incident edge (e.g. “R_plate”),
or None for a connection straight to a reserved net / rail.
role: NeighborRoleInferred role of the neighbour.