pub struct SplitCompiledPedal {
pub pre: CompiledPedal,
pub post: CompiledPedal,
}Expand description
A split compiled pedal — pre-section and post-section with an FX loop between them.
Fields
pre: CompiledPedalpost: CompiledPedalImplementations
Sourceimpl SplitCompiledPedal
impl SplitCompiledPedal
Sourcepub fn process(&mut self, input: f64) -> f64
pub fn process(&mut self, input: f64) -> f64
Process with no FX loop — direct connection from pre to post.
Sourcepub fn process_pre(&mut self, input: f64) -> f64
pub fn process_pre(&mut self, input: f64) -> f64
Process the pre-section only, returning the FX send signal.
Sourcepub fn process_post(&mut self, fx_return: f64) -> f64
pub fn process_post(&mut self, fx_return: f64) -> f64
Process the post-section only, taking the FX return signal.
pub fn set_sample_rate(&mut self, rate: f64)
pub fn reset(&mut self)
pub fn set_control(&mut self, label: &str, value: f64)
Sourcepub fn input_impedance(&self) -> f64
pub fn input_impedance(&self) -> f64
Get the input impedance of the split pedal (Ω).
Returns the input impedance of the pre-section.
Sourcepub fn output_impedance(&self) -> f64
pub fn output_impedance(&self) -> f64
Get the output impedance of the split pedal (Ω).
Returns the output impedance of the post-section.