CapType

Enum CapType 

pub enum CapType {
    Film,
    Electrolytic,
    Ceramic,
    Tantalum,
}
Capacitor dielectric types with different parasitic characteristics.

Different dielectric materials have different leakage and dielectric absorption properties. Film caps are nearly ideal, while electrolytics have significant leakage and aging effects.

Variants



Film

Film capacitor (polyester, polypropylene, etc.) Negligible leakage, no dielectric absorption. Used in: coupling caps, tone stacks, most pedal applications.



Electrolytic

Electrolytic capacitor (aluminum, tantalum). Significant leakage (typ. 100kΩ-10MΩ parallel resistance). Aging increases leakage. Can exhibit dielectric absorption. Used in: power supply filtering, bias decoupling, large coupling caps.



Ceramic

Ceramic capacitor (X7R, C0G/NP0, Y5V). Low leakage but can have voltage coefficient (capacitance changes with voltage). C0G/NP0 types are stable; X7R/Y5V lose capacitance under DC bias. Used in: HF bypass, decoupling, RF applications.



Tantalum

Tantalum capacitor (solid electrolytic). Better leakage than aluminum electrolytic, smaller size. Used in: compact designs, stable bypass applications.