pub fn pentode_model_by_name(name: &str) -> PentodeModelExpand description
Look up a pentode model by name from the model registry. Panics if the name is not found.
pub fn pentode_model_by_name(name: &str) -> PentodeModelLook up a pentode model by name from the model registry. Panics if the name is not found.