pub fn triode_model_by_name(name: &str) -> TriodeModelExpand description
Look up a triode model by name from the model registry. Panics if the name is not found.
pub fn triode_model_by_name(name: &str) -> TriodeModelLook up a triode model by name from the model registry. Panics if the name is not found.