pub fn bjt_by_name(name: &str) -> Option<&'static SpiceBjtModel>Expand description
Look up a BJT model by name (case-insensitive).
Returns None if the model name is not found in the embedded model file.
pub fn bjt_by_name(name: &str) -> Option<&'static SpiceBjtModel>Look up a BJT model by name (case-insensitive).
Returns None if the model name is not found in the embedded model file.