pub fn jfet_by_name(name: &str) -> Option<&'static SpiceJfetModel>Expand description
Look up a JFET model by name (case-insensitive).
Returns None if the model name is not found in the embedded model file.
pub fn jfet_by_name(name: &str) -> Option<&'static SpiceJfetModel>Look up a JFET model by name (case-insensitive).
Returns None if the model name is not found in the embedded model file.